@@ -2,7 +2,7 @@ package Test2::Harness::UI::Sweeper;
 use strict;
 use warnings;
 
-our $VERSION = '0.000067';
+our $VERSION = '0.000068';
 
 use Test2::Harness::UI::Util::HashBase qw{
     <config
@@ -37,7 +37,11 @@ sub sweep {
         $counts{runs}++;
         my $jobs = $run->jobs;
 
-        $run->coverage->delete if $run->coverage_id;
+        if ($run->coverage_id) {
+            my $coverage = $run->coverage;
+            $run->update({coverage_id => undef});
+            $coverage->delete;
+        }
 
         while (my $job = $jobs->next()) {
             $counts{jobs}++;
